==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectMatchFluent<A extends EnvoyFilterEnvoyConfigObjectMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchFluent() {
  }
  public EnvoyFilterEnvoyConfigObjectMatchFluent(EnvoyFilterEnvoyConfigObjectMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatch());

    if (instance != null) {
      this.withObjectTypes(instance.getObjectTypes());
      this.withContext(instance.getContext());
      this.withProxy(instance.getProxy());
      this.withObjectTypes(instance.getObjectTypes());
      this.withContext(instance.getContext());
      this.withProxy(instance.getProxy());
    }
  }
  private VisitableBuilder<? extends IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes,?> objectTypes;
  private EnvoyFilterPatchContext context;
  private EnvoyFilterProxyMatchBuilder proxy;
  public IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes buildObjectTypes() {
    return this.objectTypes!=null?this.objectTypes.build():null;
  }
  public A withObjectTypes(IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes objectTypes) {
    if (objectTypes==null){ this.objectTypes = null; _visitables.remove("objectTypes"); return (A) this;}
    VisitableBuilder<? extends IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes,?> builder = builder(objectTypes); _visitables.get("objectTypes").clear();_visitables.get("objectTypes").add(builder);this.objectTypes = builder;
    return (A) this;
  }
  public boolean hasObjectTypes() {
    return this.objectTypes != null;
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchListenerTypes() {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested(null);
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchListenerTypesLike(EnvoyFilterEnvoyConfigObjectMatchListener item) {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested(item);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypes() {
    return new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested(null);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesLike(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration item) {
    return new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested(item);
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchClusterTypes() {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested(null);
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchClusterTypesLike(EnvoyFilterEnvoyConfigObjectMatchCluster item) {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested(item);
  }
  public EnvoyFilterPatchContext getContext() {
    return this.context;
  }
  public A withContext(EnvoyFilterPatchContext context) {
    this.context=context; return (A) this;
  }
  public boolean hasContext() {
    return this.context != null;
  }
  public EnvoyFilterProxyMatch buildProxy() {
    return this.proxy!=null ?this.proxy.build():null;
  }
  public A withProxy(EnvoyFilterProxyMatch proxy) {
    _visitables.get("proxy").remove(this.proxy);
    if (proxy!=null){ this.proxy= new EnvoyFilterProxyMatchBuilder(proxy); _visitables.get("proxy").add(this.proxy);} else { this.proxy = null; _visitables.get("proxy").remove(this.proxy); } return (A) this;
  }
  public boolean hasProxy() {
    return this.proxy != null;
  }
  public ProxyNested<A> withNewProxy() {
    return new ProxyNested(null);
  }
  public ProxyNested<A> withNewProxyLike(EnvoyFilterProxyMatch item) {
    return new ProxyNested(item);
  }
  public ProxyNested<A> editProxy() {
    return withNewProxyLike(java.util.Optional.ofNullable(buildProxy()).orElse(null));
  }
  public ProxyNested<A> editOrNewProxy() {
    return withNewProxyLike(java.util.Optional.ofNullable(buildProxy()).orElse(new EnvoyFilterProxyMatchBuilder().build()));
  }
  public ProxyNested<A> editOrNewProxyLike(EnvoyFilterProxyMatch item) {
    return withNewProxyLike(java.util.Optional.ofNullable(buildProxy()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchFluent that = (EnvoyFilterEnvoyConfigObjectMatchFluent) o;
    if (!java.util.Objects.equals(objectTypes, that.objectTypes)) return false;

    if (!java.util.Objects.equals(context, that.context)) return false;

    if (!java.util.Objects.equals(proxy, that.proxy)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(objectTypes,  context,  proxy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (objectTypes != null) { sb.append("objectTypes:"); sb.append(objectTypes + ","); }
    if (context != null) { sb.append("context:"); sb.append(context + ","); }
    if (proxy != null) { sb.append("proxy:"); sb.append(proxy); }
    sb.append("}");
    return sb.toString();
  }
  protected static <T>VisitableBuilder<T,?> builder(Object item) {
    switch (item.getClass().getName()) {
    case "io.fabric8.istio.api.networking.v1alpha3."+"EnvoyFilterEnvoyConfigObjectMatchListener": return (VisitableBuilder<T, ?>)new EnvoyFilterEnvoyConfigObjectMatchListenerBuilder((EnvoyFilterEnvoyConfigObjectMatchListener) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration": return (VisitableBuilder<T, ?>)new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder((EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"EnvoyFilterEnvoyConfigObjectMatchCluster": return (VisitableBuilder<T, ?>)new EnvoyFilterEnvoyConfigObjectMatchClusterBuilder((EnvoyFilterEnvoyConfigObjectMatchCluster) item);
    }
 return (VisitableBuilder<T, ?>)builderOf(item);
  }
  public class EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<N> extends EnvoyFilterEnvoyConfigObjectMatchListenerFluent<EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<N>> implements Nested<N>{
    EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested(EnvoyFilterEnvoyConfigObjectMatchListener item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectMatchListenerBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withObjectTypes(builder.build());
    }
    public N endEnvoyFilterEnvoyConfigObjectMatchListenerTypes() {
      return and();
    }
    
  }
  public class EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<N> extends EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<N>> implements Nested<N>{
    EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withObjectTypes(builder.build());
    }
    public N endEnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypes() {
      return and();
    }
    
  }
  public class EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<N> extends EnvoyFilterEnvoyConfigObjectMatchClusterFluent<EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<N>> implements Nested<N>{
    EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested(EnvoyFilterEnvoyConfigObjectMatchCluster item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchClusterBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectMatchClusterBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withObjectTypes(builder.build());
    }
    public N endEnvoyFilterEnvoyConfigObjectMatchClusterTypes() {
      return and();
    }
    
  }
  public class ProxyNested<N> extends EnvoyFilterProxyMatchFluent<ProxyNested<N>> implements Nested<N>{
    ProxyNested(EnvoyFilterProxyMatch item) {
      this.builder = new EnvoyFilterProxyMatchBuilder(this, item);
    }
    EnvoyFilterProxyMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withProxy(builder.build());
    }
    public N endProxy() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EnvoyFilterEnvoyConfigObjectMatchFluent<A extends EnvoyFilterEnvoyConfigObjectMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchFluent() {
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchFluent(EnvoyFilterEnvoyConfigObjectMatch instance) {
    this.copyInstance(instance);
  }
  private VisitableBuilder<? extends IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes,?> objectTypes;
  private EnvoyFilterPatchContext context;
  private EnvoyFilterProxyMatchBuilder proxy;
  
  protected void copyInstance(EnvoyFilterEnvoyConfigObjectMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatch());
  
    if (instance != null) {
        this.withObjectTypes(instance.getObjectTypes());
        this.withContext(instance.getContext());
        this.withProxy(instance.getProxy());
        this.withObjectTypes(instance.getObjectTypes());
        this.withContext(instance.getContext());
        this.withProxy(instance.getProxy());
      }
  }
  
  public IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes buildObjectTypes() {
    return this.objectTypes!=null?this.objectTypes.build():null;
  }
  
  public A withObjectTypes(IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes objectTypes) {
    if (objectTypes==null){ this.objectTypes = null; _visitables.remove("objectTypes"); return (A) this;}
    VisitableBuilder<? extends IsEnvoyFilterEnvoyConfigObjectMatchObjectTypes,?> builder = builder(objectTypes); _visitables.get("objectTypes").clear();_visitables.get("objectTypes").add(builder);this.objectTypes = builder;
    return (A) this;
  }
  
  public boolean hasObjectTypes() {
    return this.objectTypes != null;
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchListenerTypes() {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested(null);
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchListenerTypesLike(EnvoyFilterEnvoyConfigObjectMatchListener item) {
    return new EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested(item);
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypes() {
    return new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested(null);
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesLike(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration item) {
    return new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested(item);
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchClusterTypes() {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested(null);
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<A> withNewEnvoyFilterEnvoyConfigObjectMatchClusterTypesLike(EnvoyFilterEnvoyConfigObjectMatchCluster item) {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested(item);
  }
  
  public EnvoyFilterPatchContext getContext() {
    return this.context;
  }
  
  public A withContext(EnvoyFilterPatchContext context) {
    this.context=context; return (A) this;
  }
  
  public boolean hasContext() {
    return this.context != null;
  }
  
  public EnvoyFilterProxyMatch buildProxy() {
    return this.proxy!=null ?this.proxy.build():null;
  }
  
  public A withProxy(EnvoyFilterProxyMatch proxy) {
    _visitables.get("proxy").remove(this.proxy);
    if (proxy!=null){ this.proxy= new EnvoyFilterProxyMatchBuilder(proxy); _visitables.get("proxy").add(this.proxy);} else { this.proxy = null; _visitables.get("proxy").remove(this.proxy); } return (A) this;
  }
  
  public boolean hasProxy() {
    return this.proxy != null;
  }
  
  public ProxyNested<A> withNewProxy() {
    return new ProxyNested(null);
  }
  
  public ProxyNested<A> withNewProxyLike(EnvoyFilterProxyMatch item) {
    return new ProxyNested(item);
  }
  
  public ProxyNested<A> editProxy() {
    return withNewProxyLike(java.util.Optional.ofNullable(buildProxy()).orElse(null));
  }
  
  public ProxyNested<A> editOrNewProxy() {
    return withNewProxyLike(java.util.Optional.ofNullable(buildProxy()).orElse(new EnvoyFilterProxyMatchBuilder().build()));
  }
  
  public ProxyNested<A> editOrNewProxyLike(EnvoyFilterProxyMatch item) {
    return withNewProxyLike(java.util.Optional.ofNullable(buildProxy()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchFluent that = (EnvoyFilterEnvoyConfigObjectMatchFluent) o;
    if (!java.util.Objects.equals(objectTypes, that.objectTypes)) return false;
  
    if (!java.util.Objects.equals(context, that.context)) return false;
  
    if (!java.util.Objects.equals(proxy, that.proxy)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(objectTypes,  context,  proxy,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (objectTypes != null) { sb.append("objectTypes:"); sb.append(objectTypes + ","); }
    if (context != null) { sb.append("context:"); sb.append(context + ","); }
    if (proxy != null) { sb.append("proxy:"); sb.append(proxy); }
    sb.append("}");
    return sb.toString();
  }
  
  protected static <T>VisitableBuilder<T,?> builder(Object item) {
    switch (item.getClass().getName()) {
    case "io.fabric8.istio.api.networking.v1alpha3."+"EnvoyFilterEnvoyConfigObjectMatchListener": return (VisitableBuilder<T, ?>)new EnvoyFilterEnvoyConfigObjectMatchListenerBuilder((EnvoyFilterEnvoyConfigObjectMatchListener) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration": return (VisitableBuilder<T, ?>)new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder((EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"EnvoyFilterEnvoyConfigObjectMatchCluster": return (VisitableBuilder<T, ?>)new EnvoyFilterEnvoyConfigObjectMatchClusterBuilder((EnvoyFilterEnvoyConfigObjectMatchCluster) item);
    }
   return (VisitableBuilder<T, ?>)builderOf(item);
  }
  public class EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<N> extends EnvoyFilterEnvoyConfigObjectMatchListenerFluent<EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested<N>> implements Nested<N>{
    EnvoyFilterEnvoyConfigObjectMatchListenerTypesNested(EnvoyFilterEnvoyConfigObjectMatchListener item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchListenerBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectMatchListenerBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withObjectTypes(builder.build());
    }
    
    public N endEnvoyFilterEnvoyConfigObjectMatchListenerTypes() {
      return and();
    }
    
  
  }
  public class EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<N> extends EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested<N>> implements Nested<N>{
    EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypesNested(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withObjectTypes(builder.build());
    }
    
    public N endEnvoyFilterEnvoyConfigObjectMatchRouteConfigurationTypes() {
      return and();
    }
    
  
  }
  public class EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<N> extends EnvoyFilterEnvoyConfigObjectMatchClusterFluent<EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested<N>> implements Nested<N>{
    EnvoyFilterEnvoyConfigObjectMatchClusterTypesNested(EnvoyFilterEnvoyConfigObjectMatchCluster item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchClusterBuilder(this, item);
    }
    EnvoyFilterEnvoyConfigObjectMatchClusterBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withObjectTypes(builder.build());
    }
    
    public N endEnvoyFilterEnvoyConfigObjectMatchClusterTypes() {
      return and();
    }
    
  
  }
  public class ProxyNested<N> extends EnvoyFilterProxyMatchFluent<ProxyNested<N>> implements Nested<N>{
    ProxyNested(EnvoyFilterProxyMatch item) {
      this.builder = new EnvoyFilterProxyMatchBuilder(this, item);
    }
    EnvoyFilterProxyMatchBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchFluent.this.withProxy(builder.build());
    }
    
    public N endProxy() {
      return and();
    }
    
  
  }

}
